@@ -5,7 +5,7 @@ from .twoterm import (Resistor, ResistorIEEE, ResistorIEC, ResistorVar, Resistor
                       DiodeShockley, Zener, Varactor, LED, LED2, Photodiode, Potentiometer, PotentiometerIEEE,
                       PotentiometerIEC, Diac, Triac, SCR, Memristor, Memristor2, Josephson, Fuse, FuseUS, FuseIEEE,
                       FuseIEC, Inductor, Inductor2, Crystal, Breaker, CPE, SparkGap, RBox, RBoxVar,
-                      PotBox, PhotoresistorBox)
+                      PotBox, PhotoresistorBox, Nullator, Norator, CurrentMirror, VoltageMirror)
 from .oneterm import Ground, GroundSignal, GroundChassis, Antenna, AntennaLoop, AntennaLoop2, Vss, Vdd, NoConnect
 from .opamp import Opamp
 from .sources import (Source, SourceV, SourceI, SourceSin, SourcePulse, SourceSquare, SourceTriangle, SourceRamp,
@@ -13,18 +13,21 @@ from .sources import (Source, SourceV, SourceI, SourceSin, SourcePulse, SourceSq
                       MeterA, MeterOhm, Lamp, Solar, Neon)
 from .switches import (Switch, SwitchSpdt, SwitchSpdt2, SwitchDpst, SwitchDpdt, Button, SwitchReed,
                        SwitchRotary, SwitchDIP)
-from .transistors import (NFet, PFet, JFet, JFetN, JFetP, Bjt, BjtNpn, BjtPnp, BjtPnp2c, Bjt2, BjtNpn2, BjtPnp2,
-                          BjtPnp2c2, NFet2, PFet2, JFet2, JFetN2, JFetP2)
+from .transistors import (NFet, PFet, AnalogNFet, AnalogPFet, AnalogBiasedFet,
+                          JFet, JFetN, JFetP, Bjt, BjtNpn, BjtPnp, BjtPnp2c, Bjt2, BjtNpn2, BjtPnp2,
+                          BjtPnp2c2, NFet2, PFet2, JFet2, JFetN2, JFetP2, NMos, PMos, NMos2, PMos2)
 from .misc import Speaker, Mic, Motor, AudioJack
 from .xform import Transformer
 from .cables import Coax, Triax
 from .intcircuits import (IcPin, Ic, Multiplexer, IcDIP, VoltageRegulator, DFlipFlop, JKFlipFlop, Ic555,
                           SevenSegment, sevensegdigit)
-from .lines import (Line, Dot, Arrowhead, Arrow, DotDotDot, Wire, Gap, Label, Tag, CurrentLabel,
+from .lines import (Line, DataBusLine, Dot, Arrowhead, Arrow, DotDotDot, Wire, Gap, Label, Tag, CurrentLabel,
                     CurrentLabelInline, ZLabel, LoopCurrent, LoopArrow, Rect, Arc2, Arc3, ArcZ, ArcN, ArcLoop,
                     Annotate, Encircle, EncircleBox)
 from .connectors import OrthoLines, RightLines, Header, Jumper, BusConnect, BusLine, DB25, DB9, CoaxConnect, Plug, Jack
 from .compound import ElementCompound, Optocoupler, Relay, Rectifier, Wheatstone
+from .twoports import (ElementTwoport, TwoPort, VoltageTransactor, TransimpedanceTransactor, CurrentTransactor,
+                       TransadmittanceTransactor, Nullor, VMCMPair)
 from .outlets import (OutletA, OutletB, OutletC, OutletD, OutletE, OutletF, OutletG, OutletH, OutletI, OutletJ,
                       OutletK, OutletL)
 
@@ -37,20 +40,24 @@ __all__ = [
     "LED", "LED2", "Photodiode", "Potentiometer", "PotentiometerIEEE", "PotentiometerIEC", "Diac", "Triac", "SCR",
     "Memristor", "Memristor2", "Josephson", "Fuse", "FuseUS", "FuseIEEE", "FuseIEC", "Inductor", "Inductor2",
     "Crystal", "Breaker", "ResistorVarIEC", "CPE", "SparkGap", "RBox", "RBoxVar", "PotBox", "PhotoresistorBox",
+    "Nullator", "Norator", "CurrentMirror", "VoltageMirror",
     "Ground", "GroundSignal", "GroundChassis", "Antenna", "AntennaLoop", "AntennaLoop2", "Vss", "Vdd", "NoConnect",
     "Opamp", "Source", "SourceV", "SourceI", "SourceSin", "SourcePulse", "SourceSquare", "SourceTriangle",
     "SourceRamp", "SourceControlled", "SourceControlledV", "SourceControlledI", "BatteryCell", "Battery", "MeterV",
     "MeterI", "MeterA", "MeterOhm", "Lamp", "Solar", "Neon", "Switch", "SwitchSpdt", "SwitchSpdt2", "SwitchDpst",
-    "SwitchDpdt", "Button", "SwitchReed", "SwitchRotary", "SwitchDIP", "NFet", "PFet", "JFet", "JFetN", "JFetP",
+    "SwitchDpdt", "Button", "SwitchReed", "SwitchRotary", "SwitchDIP", "NFet", "PFet", "AnalogNFet", "AnalogPFet",
+    "AnalogBiasedFet", "JFet", "JFetN", "JFetP",
     "Bjt", "BjtNpn", "BjtPnp", "BjtPnp2c", "Bjt2", "BjtNpn2", "BjtPnp2", "BjtPnp2c2", "NFet2", "PFet2", "JFet2",
-    "JFetN2", "JFetP2", "Speaker", "Mic", "Motor", "AudioJack", "Transformer", "Coax", "Triax",
+    "JFetN2", "JFetP2", "NMos", "PMos", "NMos2", "PMos2",
+    "Speaker", "Mic", "Motor", "AudioJack", "Transformer", "Coax", "Triax",
     "IcPin", "Ic", "Multiplexer", "IcDIP", "VoltageRegulator", "DFlipFlop", "JKFlipFlop", "Ic555", "SevenSegment",
-    "sevensegdigit", "Line", "Dot", "Annotate", "ZLabel", "Arrowhead", "Arrow", "DotDotDot", "Wire",
+    "sevensegdigit", "Line", "DataBusLine", "Dot", "Annotate", "ZLabel", "Arrowhead", "Arrow", "DotDotDot", "Wire",
     "Gap", "Label", "Tag", "CurrentLabel", "CurrentLabelInline", "LoopCurrent", "LoopArrow", "Rect",
     "Arc2", "Arc3", "ArcZ", "ArcN", "ArcLoop", "Encircle", "EncircleBox", "OrthoLines", "RightLines", "Header",
     "Jumper", "BusConnect", "BusLine", "DB25", "DB9", "CoaxConnect", "Plug", "Jack", "ElementCompound", "Optocoupler",
-    "Relay", "Rectifier", "Wheatstone", "OutletA", "OutletB", "OutletC", "OutletD", "OutletE", "OutletF", "OutletG",
-    "OutletH", "OutletI", "OutletJ", "OutletK", "OutletL"]
+    "Relay", "Rectifier", "Wheatstone", "ElementTwoport", "TwoPort", "VoltageTransactor", "TransimpedanceTransactor",
+    "CurrentTransactor", "TransadmittanceTransactor", "Nullor", "VMCMPair", "OutletA", "OutletB", "OutletC", "OutletD",
+    "OutletE", "OutletF", "OutletG", "OutletH", "OutletI", "OutletJ", "OutletK", "OutletL"]
 
 
 STYLE_IEEE = {'Resistor': ResistorIEEE,
