@@ -1,7 +1,7 @@
 ''' Schemdraw base Element class '''
 
 from __future__ import annotations
-from typing import Sequence, MutableMapping, Any, Union
+from typing import Sequence, MutableMapping, Any, Union, Optional
 from collections import ChainMap
 from dataclasses import dataclass
 import warnings
@@ -71,9 +71,15 @@ class Element:
         self.segments: list[SegmentType] = []
         self.transform = Transform(0, [0, 0])
 
+        # defines whether a current label can be drawn on each side
+        self._allowed_sides = [False, True, False, True]  # right, top, left, bottom
+        self._bias_direction = None  # defines direction of bias current 'right', 'top', 'left', 'bottom', or None
+
         if 'xy' in self._userparams:  # Allow legacy 'xy' parameter
             self._userparams.setdefault('at', self._userparams.pop('xy'))
         if d:
+            warnings.warn('Positional argument d is deprecated. Use keyword direction or direction method.',
+                          DeprecationWarning, stacklevel=2)
             self._userparams['d'] = d[0]
             if len(d) > 1:
                 warnings.warn('Unused positional arguments in Element.')
@@ -270,10 +276,20 @@ class Element:
                 mathfont: Name/font-family of math text
                 color: Color of label
         '''
-        if halign is None and valign is None:
-            align = None
+        if not halign and not valign:
+            align: Optional[Align] = None
         else:
-            align = (halign, valign)
+            if not halign:
+                halign = {'top': 'center',
+                          'bottom': 'center',
+                          'left': 'right',
+                          'right': 'left'}.get(loc, 'left')  # type: ignore
+            if not valign:
+                valign = {'top': 'baseline',
+                          'bottom': 'top',
+                          'left': 'center',
+                          'right': 'center'}.get(loc, 'bottom')  # type: ignore
+            align = (halign, valign)  # type: ignore
         if not rotate:
             rotate = 0
         elif isinstance(rotate, bool):
@@ -428,7 +444,7 @@ class Element:
         return BBox(xmin, ymin, xmax, ymax)
 
     def _place_label(self, label: str, loc: LabelLoc = None,
-                     ofst: XY | float | None = None, align: Align = (None, None),
+                     ofst: XY | float | None = None, align: Align = ('left', 'bottom'),
                      rotation: float = 0, fontsize: float = None,
                      font: str = None, mathfont: str = None, color: str = None) -> None:
         ''' Adds the label Segment to the element, AFTER element placement
@@ -637,7 +653,7 @@ class Element:
     def _draw_on_figure(self):
         ''' Draw the element on a new figure. Useful for _repr_ functions. '''
         if default_canvas.default_canvas == 'matplotlib':
-            fig = mplFigure(bbox=self.get_bbox(transform=True))
+            fig = mplFigure()
         else:
             fig = svgFigure(bbox=self.get_bbox(transform=True))
         if not self._cparams:
@@ -665,6 +681,32 @@ class Element:
         for segment in self.segments:
             segment.draw(fig, self.transform, **self._cparams)
 
+    def _get_allowed_sides(self):
+        allowed_sides = self._allowed_sides
+        if self._userparams.get('reverse', False):
+            allowed_sides[0], allowed_sides[2] = allowed_sides[2], allowed_sides[0]
+        if self._userparams.get('flip', False):
+            allowed_sides[1], allowed_sides[3] = allowed_sides[3], allowed_sides[1]
+        return allowed_sides
+
+    def _get_bias_angle(self):
+        bias_direction = self._bias_direction
+        if bias_direction is None:
+            return None
+
+        map_bias = {'top': 'top', 'left': 'left', 'bottom': 'bottom', 'right': 'right'}
+
+        if self._userparams.get('reverse', False):
+            map_bias['left'] = 'right'
+            map_bias['right'] = 'left'
+        if self._userparams.get('flip', False):
+            map_bias['top'] = 'bottom'
+            map_bias['bottom'] = 'top'
+
+        map_angle = {'top': 90, 'left': 180, 'bottom': 270, 'right': 0}
+
+        return map_angle[map_bias[self._bias_direction]]
+
 
 class ElementDrawing(Element):
     ''' Create an element from a Drawing
