@@ -2,13 +2,12 @@
 
 from __future__ import annotations
 from typing import Sequence, Union
-import warnings
 import math
 
 from ..segments import Segment, SegmentCircle, SegmentArc, SegmentPoly, SegmentBezier
 from .elements import Element, Element2Term
 from .twoterm import gap
-from ..types import XY, Point, Arcdirection, BilateralDirection
+from ..types import XY, Point, Arcdirection, BilateralDirection, Linestyle
 from .. import util
 
 
@@ -26,6 +25,16 @@ class Line(Element2Term):
                                      arrowwidth=arrowwidth, arrowlength=arrowlength))
 
 
+bus_stroke = 0.25
+class DataBusLine(Element2Term):
+    ''' Straight Line with bus indication stripe '''
+    def __init__(self, *d, **kwargs):
+        super().__init__(*d, **kwargs)
+        self.segments.append(Segment(
+            [(0, 0), gap, (-bus_stroke/2, bus_stroke), (bus_stroke/2, -bus_stroke),
+             gap, (0, 0)]))
+
+
 class Arrow(Line):
     ''' Arrow
 
@@ -654,9 +663,12 @@ class CurrentLabel(Element):
             length: Length of the arrow
             top: Draw arrow on top or bottom of element
             reverse: Reverse the arrow direction
+            headlength: Length of arrowhead
+            headwidth: Width of arrowhead
     '''
     def __init__(self, ofst: float = 0.4, length: float = 2,
-                 top: bool = True, reverse: bool = False, **kwargs):
+                 top: bool = True, reverse: bool = False,
+                 headlength: float = 0.3, headwidth: float = 0.2, **kwargs):
         super().__init__(**kwargs)
         self.params['lblofst'] = -.1
         self.params['drop'] = None
@@ -666,6 +678,9 @@ class CurrentLabel(Element):
         self._length = length
         self._top = top
         self._reverse = reverse
+        self._headlength = headlength
+        self._headwidth = headwidth
+        self._reverse_flow = False
 
     def at(self, xy: XY | Element) -> 'Element':  # type: ignore[override]
         ''' Specify CurrentLabel position.
@@ -682,14 +697,44 @@ class CurrentLabel(Element):
             try:
                 pos = xy.center
             except AttributeError:
-                bbox = xy.get_bbox()
-                pos = Point(((bbox.xmax + bbox.xmin)/2, (bbox.ymax + bbox.ymin)/2))
+                bbox = xy.get_bbox(transform=True)
+                pos = Point(((bbox.xmax + bbox.xmin) / 2, (bbox.ymax + bbox.ymin) / 2))
             super().at(pos)
 
-            theta = xy.transform.theta
-            if (theta % 360) > 90 and (theta % 360) <= 270:
-                theta += 180  # Keeps 'top=True' labels above the element
+            # Every element has 4 sides where a current label could be placed, but not all are allowed
+            # In a resistor, the top and bottom are allowed, but not the sides. In a transistor, only the side of the
+            # channel is allowed. Otherwise, the current label would overlap the terminals, which wouldn't make sense.
+            #
+            # This code calculates the angles for the allowed sides of the components. If the current label is desired
+            # to be on top, it picks the closest angle to the top. Otherwise, it picks the closest angle to the
+            # top of the component in the drawing frame. If the label is flipped, it will pick the opposite angle.
+            # If at most two opposite sides are allowed, this gives the user freedom to put the label at any allowed
+            # side.
+            target_theta = xy.transform.theta
+            theta = target_theta
+            allowed_angles = [theta + angle for angle, allowed in zip([0, 90, 180, 270], xy._get_allowed_sides()) if
+                              allowed]
+
+            if self._top:
+                preferred_angle = 90
+            else:
+                preferred_angle = 90 + theta if not self.flip else -90 + theta
+
+            # find which allowed angle is closest to the preferred angle
+            differences_to_top = [abs(((angle - preferred_angle) + 180) % 360 - 180) for angle in allowed_angles]
+            theta = allowed_angles[differences_to_top.index(min(differences_to_top))]
+
+            # since current arrow is drawn on top by default, subtract 90 degree for rotation top to right side
+            theta = theta - 90
             self.theta(theta)
+
+            bias_angle = xy._get_bias_angle()
+            if bias_angle is None:
+                self._reverse_flow = False
+            else:
+                bias_angle_difference = ((bias_angle + target_theta - theta) + 180) % 360 - 180
+                self._reverse_flow = abs(bias_angle_difference) > 90
+
             if 'color' in xy._userparams:
                 self.color(xy._userparams.get('color'))
         else:
@@ -697,15 +742,20 @@ class CurrentLabel(Element):
         return self
 
     def _place(self, dwgxy, dwgtheta, **dwgparams):
-        if not self._top:
-            self._ofst = -self._ofst
+        angle_difference = ((self._userparams.get('theta', 0) - 180) + 180) % 360 - 180
+        change_label = (angle_difference > -90) and (angle_difference <= 90)
+        if change_label:
             self.params['lblloc'] = 'bot'
-        a, b = (-self._length/2, self._ofst), (self._length/2, self._ofst)
+
+        a, b = (-self._length / 2, self._ofst), (self._length / 2, self._ofst)
+
+        if self._reverse_flow:
+            a, b = b, a
 
         if self._reverse:
             a, b = b, a
 
-        self.segments.append(Segment((a, b), arrow='->', arrowwidth=.2, arrowlength=.3))
+        self.segments.append(Segment((a, b), arrow='->', arrowwidth=self._headwidth, arrowlength=self._headlength))
         return super()._place(dwgxy, dwgtheta, **dwgparams)
 
 
@@ -931,12 +981,16 @@ class Rect(Element):
         Args:
             corner1: Position of top-left corner
             corner2: Position of bottom-right corner
+            fill: Color to fill if not None
+            lw: Line width
+            ls: Line style '-', '--', ':', etc.
     '''
-    def __init__(self, *d, corner1: XY = (0, 0), corner2: XY = (1, 1), **kwargs):
+    def __init__(self, *d, corner1: XY = (0, 0), corner2: XY = (1, 1),
+                 fill: str = None, lw: float = None, ls: Linestyle = None, **kwargs):
         super().__init__(*d, **kwargs)
         c1a = (corner1[0], corner2[1])
         c2a = (corner2[0], corner1[1])
-        self.segments.append(Segment([corner1, c1a, corner2, c2a, corner1], zorder=0))
+        self.segments.append(Segment([corner1, c1a, corner2, c2a, corner1], zorder=0, fill=fill, lw=lw, ls=ls))
         self.params['zorder'] = 0   # Put on bottom
 
 
