@@ -9,7 +9,7 @@ from typing import Sequence, Any, Union
 import warnings
 import math
 
-from .types import BBox, XY, Linestyle, Capstyle, Joinstyle, Align, Arcdirection, EndRef, RotationMode
+from .types import BBox, XY, Linestyle, Capstyle, Joinstyle, Align, Arcdirection, EndRef, RotationMode, Halign, Valign
 from . import util
 from .util import Point
 from .backends import svg
@@ -143,7 +143,7 @@ class Segment:
             'capstyle': self.capstyle if self.capstyle else style.get('capstyle', None),
             'joinstyle': self.joinstyle if self.joinstyle else style.get('joinstyle', None),
             'visible': self.visible}
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
         return Segment(transform.transform_array(self.path), **params)
 
@@ -259,6 +259,7 @@ class SegmentText:
                 'top', 'bottom')
             rotation: Rotation angle in degrees
             rotation_mode: See Matplotlib documentation. 'anchor' or 'default'.
+            rotation_global: Lock rotation to world rather than component. Defaults to True
             color: Color for this segment
             fontsize: Font size
             font: Font name/family
@@ -271,6 +272,7 @@ class SegmentText:
                  align: Align = None,
                  rotation: float = None,
                  rotation_mode: RotationMode = None,
+                 rotation_global: bool = True,
                  color: str = None,
                  fontsize: float = 14,
                  font: str = None,
@@ -287,6 +289,7 @@ class SegmentText:
         self.color = color
         self.rotation = rotation
         self.rotation_mode = rotation_mode
+        self.rotation_global = rotation_global
         self.clip = clip
         self.zorder = zorder
         self.visible = visible
@@ -294,10 +297,17 @@ class SegmentText:
     def doreverse(self, centerx: float) -> None:
         ''' Reverse the path (flip horizontal about the centerx point) '''
         self.xy = util.mirrorx(self.xy, centerx)
+        if not self.rotation_global and self.align is not None:
+            align_lookup: dict[str, Halign] = {'center': 'center', 'left': 'right', 'right': 'left'}
+            leftalign = align_lookup.get(self.align[0], 'left')
+            self.align = (leftalign, self.align[1])
 
     def doflip(self) -> None:
         ''' Vertically flip the element '''
         self.xy = util.flip(self.xy)
+        if not self.rotation_global and self.align is not None:
+            align_lookup: dict[str, Valign] = {'center': 'center', 'top': 'bottom', 'bottom': 'top'}
+            self.align = (self.align[0], align_lookup.get(self.align[1], 'bottom'))
 
     def xform(self, transform, **style) -> 'SegmentText':
         ''' Return a new Segment that has been transformed
@@ -315,12 +325,19 @@ class SegmentText:
             'color': self.color if self.color else style.get('color', None),
             'rotation': self.rotation if self.rotation else style.get('rotation', None),
             'rotation_mode': self.rotation_mode if self.rotation_mode else style.get('rotation_mode', None),
+            'rotation_global': self.rotation_global,
             'clip': self.clip,
             'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
             'visible': self.visible}
 
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
+        if not params['rotation_global']:
+            if params['rotation'] is None:
+                params['rotation'] = transform.theta
+            else:
+                params['rotation'] = params['rotation'] + transform.theta % 360
+
         return SegmentText(transform.transform(self.xy),
                            self.text, **params)
 
@@ -370,6 +387,12 @@ class SegmentText:
         rotmode = self.rotation_mode if self.rotation_mode else style.get('rotation_mode', 'anchor')
         zorder = self.zorder if self.zorder is not None else style.get('zorder', 3)
 
+        if not self.rotation_global:
+            if rotation is None:
+                rotation = transform.theta
+            else:
+                rotation = rotation + transform.theta % 360
+
         fig.text(self.text, xy[0], xy[1],
                  color=color, fontsize=fontsize, fontfamily=font, mathfont=mathfont,
                  rotation=rotation, rotation_mode=rotmode,
@@ -448,7 +471,7 @@ class SegmentPoly:
             'clip': self.clip,
             'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
             'visible': self.visible}
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
         return SegmentPoly(transform.transform_array(self.verts), **params)
 
@@ -561,7 +584,7 @@ class SegmentCircle:
             'clip': self.clip,
             'ref': self.endref,
             'visible': self.visible}
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
         return SegmentCircle(transform.transform(self.center),
                              self.radius*transform.zoom, **params)
@@ -679,7 +702,7 @@ class SegmentBezier:
             'clip': self.clip,
             'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
             'visible': self.visible}
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
         return SegmentBezier(transform.transform_array(self.p), **params)
 
@@ -786,7 +809,7 @@ class SegmentArc:
             'clip': self.clip,
             'zorder': self.zorder if self.zorder is not None else style.get('zorder', None),
             'visible': self.visible}
-        style = {k: v for k, v in style.items() if params.get(k) is not None}
+        style = {k: v for k, v in style.items() if params.get(k) is None and k in params.keys()}
         params.update(style)
         return SegmentArc(transform.transform(self.center),
                           self.width*transform.zoom, self.height*transform.zoom, angle=angle,
